'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGIX_sprite'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGIX_sprite',error_checker=_errors._error_checker)
GL_SPRITE_AXIAL_SGIX=_C('GL_SPRITE_AXIAL_SGIX',0x814C)
GL_SPRITE_AXIS_SGIX=_C('GL_SPRITE_AXIS_SGIX',0x814A)
GL_SPRITE_EYE_ALIGNED_SGIX=_C('GL_SPRITE_EYE_ALIGNED_SGIX',0x814E)
GL_SPRITE_MODE_SGIX=_C('GL_SPRITE_MODE_SGIX',0x8149)
GL_SPRITE_OBJECT_ALIGNED_SGIX=_C('GL_SPRITE_OBJECT_ALIGNED_SGIX',0x814D)
GL_SPRITE_SGIX=_C('GL_SPRITE_SGIX',0x8148)
GL_SPRITE_TRANSLATION_SGIX=_C('GL_SPRITE_TRANSLATION_SGIX',0x814B)
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glSpriteParameterfSGIX(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glSpriteParameterfvSGIX(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glSpriteParameteriSGIX(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glSpriteParameterivSGIX(pname,params):pass



'''OpenGL extension OES.point_size_array

This module customises the behaviour of the 
OpenGL.raw.GLES1.OES.point_size_array to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/point_size_array.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.OES.point_size_array import *
from OpenGL.raw.GLES1.OES.point_size_array import _EXTENSION_NAME

def glInitPointSizeArrayOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glPointSizePointerOES.pointer size not checked against 'type,stride'
glPointSizePointerOES=wrapper.wrapper(glPointSizePointerOES).setInputArraySize(
    'pointer', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension NVX.gpu_memory_info

This module customises the behaviour of the 
OpenGL.raw.GL.NVX.gpu_memory_info to provide a more 
Python-friendly API

Overview (from the spec)
	
	Most graphics systems offer a limited amount of onboard
	high-performance memory for storing textures, geometric
	primitives, and other data used for rendering.
	
	OpenGL implementations are expected to manage the residence of
	objects (that is, the memory pools in which objects are placed)
	automatically.  This is simple for applications to use, and the
	high level of abstraction allows many different underlying
	hardware implementations.  However performance sensitive 
	applications that are willing to adjust their usage of these memory 
	resources in order to maintain their desired performance are unable 
	to determine when the limited onboard memory resources are 
	approaching full utilization and swapping (with its related 
	performance impact) is imminent.
	
	GL_NVX_gpu_memory_info provides applications visibility into GPU 
	hardware memory utilization in order to allow the application to 
	effectively manage its resource allocations in the scope of the 
	current available GPU memory.  This information is made available 
	to the applications in the form of the total available resource 
	size (after initial system allocations) and the current available 
	resource (e.g. free memory) as well as a count of the number and
	total size of evictions of data from GPU memory since the last time
	this information was queried from this context using this extension.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NVX/gpu_memory_info.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NVX.gpu_memory_info import *
from OpenGL.raw.GL.NVX.gpu_memory_info import _EXTENSION_NAME

def glInitGpuMemoryInfoNVX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_AMD_name_gen_delete'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_AMD_name_gen_delete',error_checker=_errors._error_checker)
GL_DATA_BUFFER_AMD=_C('GL_DATA_BUFFER_AMD',0x9151)
GL_PERFORMANCE_MONITOR_AMD=_C('GL_PERFORMANCE_MONITOR_AMD',0x9152)
GL_QUERY_OBJECT_AMD=_C('GL_QUERY_OBJECT_AMD',0x9153)
GL_SAMPLER_OBJECT_AMD=_C('GL_SAMPLER_OBJECT_AMD',0x9155)
GL_VERTEX_ARRAY_OBJECT_AMD=_C('GL_VERTEX_ARRAY_OBJECT_AMD',0x9154)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLuintArray)
def glDeleteNamesAMD(identifier,num,names):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLuintArray)
def glGenNamesAMD(identifier,num,names):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLenum,_cs.GLuint)
def glIsNameAMD(identifier,name):pass



'''OpenGL extension AMD.vertex_shader_tessellator

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.vertex_shader_tessellator to provide a more 
Python-friendly API

Overview (from the spec)
	
	The vertex shader tessellator gives new flexibility to the shader
	author to shade at a tessellated vertex, rather than just at a
	provided vertex.
	
	In unextended vertex shading, the built-in attributes such as
	gl_Vertex, gl_Normal, and gl_MultiTexcoord0, together with the
	user defined attributes, are system provided values which are
	initialized prior to vertex shader invocation.
	
	With vertex shading tessellation, additional vertex shader special 
	values are available:
	
	    ivec3 gl_VertexTriangleIndex; // indices of the three control
	                                  // points for the vertex
	    vec3 gl_BarycentricCoord;     // barycentric coordinates
	                                  // of the vertex
	
	i o
	  |\
	  | \
	  *--*
	  |\ |\
	  | \| \
	  *--*--*
	  |\ |\ |\
	  | \| \| \
	j o--*--*--o k
	
	Figure 1  A Tessellated Triangle
	o = control point (and tessellated vertex)
	* = tessellated vertex
	
	    ivec4 gl_VertexQuadIndex;   // indices for the four control
	                                // points for the vertex
	    vec2 gl_UVCoord;            // UV coordinates of the vertex
	
	i o--*--*--o k
	  |\ |\ |\ | 
	  | \| \| \|
	  *--*--*--*
	  |\ |\ |\ | 
	  | \| \| \|
	  *--*--*--*
	  |\ |\ |\ | 
	  | \| \| \|
	j o--*--*--o l
	
	Figure 2  A Tessellated Quad
	o = control point (and tessellated vertex)
	* = tessellated vertex
	
	When this extension is enabled, conventional built-in attributes
	and user defined attributes are uninitialized.  The shader writer
	is responsible for explicitly fetching all other vertex data either
	from textures, uniform buffers, or vertex buffers.
	
	The shader writer is further responsible for interpolating 
	the vertex data at the given barycentric coordinates or uv
	coordinates of the vertex.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/vertex_shader_tessellator.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.vertex_shader_tessellator import *
from OpenGL.raw.GL.AMD.vertex_shader_tessellator import _EXTENSION_NAME

def glInitVertexShaderTessellatorAMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION